.. pip_shims documentation master file, created by
   sphinx-quickstart on Wed Aug  8 16:03:25 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pip_shims's documentation!
=====================================

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   quickstart
   pip_shims


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
